<?php

namespace Litecms\Legal\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Legal\Events\LegalAction as LegalActionEvent;
use Litecms\Legal\Notifications\LegalAction as LegalActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LegalAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LegalActionEvent.
     *
     * @param   LegalActionEvent  $event
     * @return mixed
     */
    public function handle(LegalActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $legal.
     *
     * @param   LegalActionEvent  $event
     * @return void
     */
    public function create(LegalActionEvent $event)
    {
        $client = $event->legal->client;
        Notification::send($client, new LegalActionNotification($event));
    }

    /**
     * Handle the LegalActionEvent as a listener.
     *
     * @param   LegalActionEvent  $event
     * @return mixed
     */
    public function asListener(LegalActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LegalActionEvent  $event
     * @return bool
     */
    private function isAllowed(LegalActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
