<?php

namespace Litecms\Legal\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Legal\Events\LegalCaseAction as LegalCaseActionEvent;
use Litecms\Legal\Notifications\LegalCaseAction as LegalCaseActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LegalCaseAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LegalCaseActionEvent.
     *
     * @param   LegalCaseActionEvent  $event
     * @return mixed
     */
    public function handle(LegalCaseActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $legal_case.
     *
     * @param   LegalCaseActionEvent  $event
     * @return void
     */
    public function create(LegalCaseActionEvent $event)
    {
        $client = $event->legal_case->client;
        Notification::send($client, new LegalCaseActionNotification($event));
    }

    /**
     * Handle the LegalCaseActionEvent as a listener.
     *
     * @param   LegalCaseActionEvent  $event
     * @return mixed
     */
    public function asListener(LegalCaseActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LegalCaseActionEvent  $event
     * @return bool
     */
    private function isAllowed(LegalCaseActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
