<?php

namespace Litecms\Legal\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Legal\Events\LegalCaseWorkflow as LegalCaseWorkflowEvent;
use Litecms\Legal\Notifications\LegalCaseWorkflow as LegalCaseWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class LegalCaseWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(LegalCaseWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $legal_case is submitted.
     *
     * @param LegalCaseWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(LegalCaseWorkflowEvent $event)
    {
        $client = $event->legal_case->client;
        Notification::send($client, new LegalCaseWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $legal_case is published.
     *
     * @param LegalCaseWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(LegalCaseWorkflowEvent $event)
    {
        $client = $event->legal_case->client;
        Notification::send($client, new LegalCaseWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $legal_case is approved.
     *
     * @param LegalCaseWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(LegalCaseWorkflowEvent $event)
    {
        $client = $event->legal_case->client;
        Notification::send($client, new LegalCaseWorkflowNotification($event));
    }

    /**
     * Handles the $legal_case workflow event as a listener.
     *
     * @param LegalCaseWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(LegalCaseWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
