<?php
namespace Litecms\Legal\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Legal\Events\LegalAction as LegalActionEvent;
use Litecms\Legal\Models\Legal;

class LegalAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $legal;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LegalActionEvent $legal
     */
    public function __construct(LegalActionEvent $legal)
    {
        $this->action = $event->action;
        $this->legal = $legal;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Legal Approved - ' . config('app.name'))
            ->view('legal::legal.email.action', ['data' => $this->legal]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
