<?php

namespace Litecms\Legal\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Legal\Models\LegalCase;

class LegalCasePolicy
{

    use LegalCaseAction;
    use LegalCaseWorkflow;

    /**
     * Determine if the given user can view the legal_case.
     *
     * @param Authenticatable $user
     * @param LegalCase $legal_case
     *
     * @return bool
     */
    public function view(Authenticatable $user, LegalCase $legal_case)
    {
        if ($authUser->canDo('legal.legal_case.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $legal_case->is_owner;
    }

    /**
     * Determine if the given user can create a legal_case.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('legal.legal_case.create');
    }

    /**
     * Determine if the given user can update the given legal_case.
     *
     * @param Authenticatable $user
     * @param LegalCase $legal_case
     *
     * @return bool
     */
    public function update(Authenticatable $user, LegalCase $legal_case)
    {
        if ($user->canDo('legal.legal_case.edit') && $user->isAdmin()) {
            return true;
        }

        return $legal_case->is_owner;
    }

    /**
     * Determine if the given user can delete the given legal_case.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, LegalCase $legal_case)
    {
        return $legal_case->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
