<?php

namespace Litecms\Legal\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Legal\Models\Legal;

class LegalPolicy
{

    use LegalAction;
    use LegalWorkflow;

    /**
     * Determine if the given user can view the legal.
     *
     * @param Authenticatable $user
     * @param Legal $legal
     *
     * @return bool
     */
    public function view(Authenticatable $user, Legal $legal)
    {
        if ($authUser->canDo('legal.legal.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $legal->is_owner;
    }

    /**
     * Determine if the given user can create a legal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('legal.legal.create');
    }

    /**
     * Determine if the given user can update the given legal.
     *
     * @param Authenticatable $user
     * @param Legal $legal
     *
     * @return bool
     */
    public function update(Authenticatable $user, Legal $legal)
    {
        if ($user->canDo('legal.legal.edit') && $user->isAdmin()) {
            return true;
        }

        return $legal->is_owner;
    }

    /**
     * Determine if the given user can delete the given legal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Legal $legal)
    {
        return $legal->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
