<?php

namespace Litecms\Legal\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Legal\Legals;

class LegalServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'legal');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'legal');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Litecms\Legal\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Legal\Providers\RouteServiceProvider::class);
        $this->app->register(\Litecms\Legal\Providers\ActionServiceProvider::class);
        $this->app->register(\Litecms\Legal\Providers\EventServiceProvider::class);
        $this->app->register(\Litecms\Legal\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.legal', function($app)
        {
            return $this->app->make(Legal::class);
        });
    }

    /**
     * Merges user's and legal's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.legal'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/legal.php', 'litecms.legal.legal'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/legal_case.php', 'litecms.legal.legal_case'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.legal'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('litecms/legal')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/legal')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/legal')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
